﻿<%@ WebService Language="C#" Class="GoogleBridge" %>

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Services;
using System.Web.Script.Services;
using System.Data.Common;
using System.Collections;
using System.Net;
using System.IO;

/// <summary>
/// Provides a bridge to Google to automatically translate a word or phrase, eliminating cross domain issues
/// </summary>
[ScriptService]
public class GoogleBridge  : System.Web.Services.WebService {
    /// <summary>
    /// Translates a string using the specified language pair
    /// See http://code.google.com/intl/de/apis/ajaxlanguage/documentation/#SupportedPairs and  http://code.google.com/intl/de/apis/ajaxlanguage/documentation/reference.html for a list of supported languages
    /// </summary>
    /// <example>{"q":"Hello World", "langpair":"en%7Cde"}</example>
    /// <param name="q">The text to translate</param>
    /// <param name="langpair">The language pair to translate, separated by an encoded pipe, %7C</param>
    /// <returns>A JSON object containing either the translated string or a responseStatus code with responseDetails</returns>
    [ScriptMethod(ResponseFormat = ResponseFormat.Json)]
    [WebMethod]
    public string Translate(string q, string langpair) {
        HttpWebRequest req = null;
        req = (HttpWebRequest)WebRequest.Create("http://ajax.googleapis.com/ajax/services/language/translate?v=1.0&q=" + q + "&langpair=" + langpair);
        req.Method = "GET";
        req.ProtocolVersion = HttpVersion.Version11;
        req.AllowAutoRedirect = false;
        req.Accept = "*/*";
        req.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1;.NET CLR 2.0.50727)";
        req.Headers.Add("Accept-Language", "en-us");
        req.KeepAlive = true;
        StreamReader reader = null;
        HttpWebResponse wr = null;
        try {
            wr = (HttpWebResponse)req.GetResponse();
            reader = new StreamReader(wr.GetResponseStream());
            string response = reader.ReadToEnd();
            return response;
        } catch(Exception ex) {
            return "{\"responseStatus\":-1, \"responseDetails\":" + ex.Message + "\"}";
        }
    }
}

